@@ -44,7 +44,7 @@ fn compile_kernel() {
     };
 
     ispc_compile::Config::new()
-        .file("thirdparty/ISPCTextureCompressor/ispc_texcomp/kernel.ispc")
+        .file("src/kernels/kernel.ispc")
         .opt_level(2)
         .optimization_opt(ispc_compile::OptimizationOpt::FastMath)
         .target_isas(target_isas.clone())
@@ -52,7 +52,7 @@ fn compile_kernel() {
         .compile("kernel");
 
     ispc_compile::Config::new()
-        .file("thirdparty/ISPCTextureCompressor/ispc_texcomp/kernel_astc.ispc")
+        .file("src/kernels/kernel_astc.ispc")
         .opt_level(2)
         .optimization_opt(ispc_compile::OptimizationOpt::FastMath)
         .target_isas(target_isas)
